/*=========================================================================

  Program:   ParaView
  Module:    vtkSMProxyManagerReviver.cxx

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkSMProxyManagerReviver.h"

#include "vtkObjectFactory.h"

//-----------------------------------------------------------------------------
vtkSMProxyManagerReviver::vtkSMProxyManagerReviver()
{
}

//-----------------------------------------------------------------------------
vtkSMProxyManagerReviver::~vtkSMProxyManagerReviver()
{
}

//-----------------------------------------------------------------------------
//-----------------------------------------------------------------------------
void vtkSMProxyManagerReviver::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}
